==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/colorbutton/lang/nl.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'nl', {
	auto: 'Automatisch',
	bgColorTitle: 'Achtergrondkleur',
	colors: {
		'000': 'Zwart',
		'800000': 'Kastanjebruin',
		'8B4513': 'Chocoladebruin',
		'2F4F4F': 'Donkerleigrijs',
		'008080': 'Blauwgroen',
		'000080': 'Marine',
		'4B0082': 'Indigo',
		'696969': 'Donkergrijs',
		B22222: 'Baksteen',
		A52A2A: 'Bruin',
		DAA520: 'Donkergeel',
		'006400': 'Donkergroen',
		'40E0D0': 'Turquoise',
		'0000CD': 'Middenblauw',
		'800080': 'Paars',
		'808080': 'Grijs',
		F00: 'Rood',
		FF8C00: 'Donkeroranje',
		FFD700: 'Goud',
		'008000': 'Groen',
		'0FF': 'Cyaan',
		'00F': 'Blauw',
		EE82EE: 'Violet',
		A9A9A9: 'Donkergrijs',
		FFA07A: 'Lichtzalm',
		FFA500: 'Oranje',
		FFFF00: 'Geel',
		'00FF00': 'Felgroen',
		AFEEEE: 'Lichtturquoise',
		ADD8E6: 'Lichtblauw',
		DDA0DD: 'Pruim',
		D3D3D3: 'Lichtgrijs',
		FFF0F5: 'Linnen',
		FAEBD7: 'Ivoor',
		FFFFE0: 'Lichtgeel',
		F0FFF0: 'Honingdauw',
		F0FFFF: 'Azuur',
		F0F8FF: 'Licht hemelsblauw',
		E6E6FA: 'Lavendel',
		FFF: 'Wit',
		'1ABC9C': 'Strong Cyan', // MISSING
		'2ECC71': 'Emerald', // MISSING
		'3498DB': 'Bright Blue', // MISSING
		'9B59B6': 'Amethyst', // MISSING
		'4E5F70': 'Grayish Blue', // MISSING
		'F1C40F': 'Vivid Yellow', // MISSING
		'16A085': 'Dark Cyan', // MISSING
		'27AE60': 'Dark Emerald', // MISSING
		'2980B9': 'Strong Blue', // MISSING
		'8E44AD': 'Dark Violet', // MISSING
		'2C3E50': 'Desaturated Blue', // MISSING
		'F39C12': 'Orange', // MISSING
		'E67E22': 'Carrot', // MISSING
		'E74C3C': 'Pale Red', // MISSING
		'ECF0F1': 'Bright Silver', // MISSING
		'95A5A6': 'Light Grayish Cyan', // MISSING
		'DDD': 'Light Gray', // MISSING
		'D35400': 'Pumpkin', // MISSING
		'C0392B': 'Strong Red', // MISSING
		'BDC3C7': 'Silver', // MISSING
		'7F8C8D': 'Grayish Cyan', // MISSING
		'999': 'Dark Gray' // MISSING
	},
	more: 'Meer kleuren...',
	panelTitle: 'Kleuren',
	textColorTitle: 'Tekstkleur'
} );

==> ldap-account-manager_7.7.orig.tar.bz2: ldap-account-manager-7.7/templates/lib/extra/ckeditor/plugins/colorbutton/lang/nl.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'nl', {
	auto: 'Automatisch',
	bgColorTitle: 'Achtergrondkleur',
	colors: {
		'000': 'Zwart',
		'800000': 'Kastanjebruin',
		'8B4513': 'Chocoladebruin',
		'2F4F4F': 'Donkerleigrijs',
		'008080': 'Blauwgroen',
		'000080': 'Marine',
		'4B0082': 'Indigo',
		'696969': 'Donkergrijs',
		B22222: 'Baksteen',
		A52A2A: 'Bruin',
		DAA520: 'Donkergeel',
		'006400': 'Donkergroen',
		'40E0D0': 'Turquoise',
		'0000CD': 'Middenblauw',
		'800080': 'Paars',
		'808080': 'Grijs',
		F00: 'Rood',
		FF8C00: 'Donkeroranje',
		FFD700: 'Goud',
		'008000': 'Groen',
		'0FF': 'Cyaan',
		'00F': 'Blauw',
		EE82EE: 'Violet',
		A9A9A9: 'Donkergrijs',
		FFA07A: 'Lichtzalm',
		FFA500: 'Oranje',
		FFFF00: 'Geel',
		'00FF00': 'Felgroen',
		AFEEEE: 'Lichtturquoise',
		ADD8E6: 'Lichtblauw',
		DDA0DD: 'Pruim',
		D3D3D3: 'Lichtgrijs',
		FFF0F5: 'Linnen',
		FAEBD7: 'Ivoor',
		FFFFE0: 'Lichtgeel',
		F0FFF0: 'Honingdauw',
		F0FFFF: 'Azuur',
		F0F8FF: 'Licht hemelsblauw',
		E6E6FA: 'Lavendel',
		FFF: 'Wit',
		'1ABC9C': 'Strong Cyan', // MISSING
		'2ECC71': 'Smaragdgroen',
		'3498DB': 'Helderblauw',
		'9B59B6': 'Amethyst', // MISSING
		'4E5F70': 'Grayish Blue', // MISSING
		'F1C40F': 'Vivid Yellow', // MISSING
		'16A085': 'Dark Cyan', // MISSING
		'27AE60': 'Dark Emerald', // MISSING
		'2980B9': 'Strong Blue', // MISSING
		'8E44AD': 'Dark Violet', // MISSING
		'2C3E50': 'Desaturated Blue', // MISSING
		'F39C12': 'Oranje',
		'E67E22': 'Wortel',
		'E74C3C': 'Pale Red', // MISSING
		'ECF0F1': 'Bright Silver', // MISSING
		'95A5A6': 'Light Grayish Cyan', // MISSING
		'DDD': 'Light Gray', // MISSING
		'D35400': 'Pompoen',
		'C0392B': 'Strong Red', // MISSING
		'BDC3C7': 'Zilver',
		'7F8C8D': 'Grayish Cyan', // MISSING
		'999': 'Donkergrijs'
	},
	more: 'Meer kleuren...',
	panelTitle: 'Kleuren',
	textColorTitle: 'Tekstkleur'
} );
